@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyAboutModule.cpp,v 1.16 2006/09/13 11:34:14 chpe Exp $
+ *  $Id: EphyAboutModule.cpp 6801 2007-01-08 23:14:15Z diegoe $
  */
 
 #include "mozilla-config.h"
@@ -276,7 +276,7 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 							_("<ul>"
 							   "<li>the service ""%s"" isn't started.</li>"
 							   "Try to start it using the Services Configuration Tool in "
-							   "Desktop > System Settings > Server Settings > Services, or</ul>"
+							   "System > Administration > Services, or</ul>"
 							   "<ul><li>the port number %d is wrong.</li>"
 							   "</ul>"),
 							serv->s_name, port);
@@ -533,10 +533,10 @@ EphyAboutModule::CreateRecoverPage(nsIURI *aRecoverURI,
 	rv = NS_NewURI(getter_AddRefs (uri), url, charset.get());
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	char *secondary = g_strdup_printf
+	char *secondary = g_markup_printf_escaped
 		(_("The page “%s” in this tab was not fully loaded yet when "
 		   "the web browser crashed; it could have caused the crash."),
-		 rawurl.get());
+		 url.get());
 
 	nsCOMPtr<nsIChannel> channel;
 	rv = WritePage (aRecoverURI, uri, uri, rawurl, title.get(),
