@@ -1,7 +1,7 @@
 /*
-*  Copyright (C) 2000 Nate Case
-*  Copyright (C) 2000-2004 Marco Pesenti Gritti
-*  Copyright (C) 2003, 2004 Christian Persch
+*  Copyright © 2000 Nate Case
+*  Copyright © 2000-2004 Marco Pesenti Gritti
+*  Copyright © 2003, 2004 Christian Persch
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
-*  $Id: mozilla-notifiers.cpp,v 1.69 2006/05/15 18:12:31 chpe Exp $
+*  $Id: mozilla-notifiers.cpp 6588 2006-09-13 11:34:25Z chpe $
 */
 
 #include "mozilla-config.h"
@@ -470,6 +470,9 @@ static const PrefData notifier_entries[] =
 	{ CONF_SECURITY_COOKIES_ACCEPT,
 	  "network.cookie.cookieBehavior",
 	  transform_cookies_accept_mode },
+	{ CONF_PRIVACY_REMEMBER_PASSWORDS,
+	  "signon.rememberSignons",
+	  mozilla_notifier_transform_bool }
 };
 
 gboolean
@@ -550,13 +553,19 @@ notify_cb (GConfClient *client,
 	GValue value = { 0, };
 
 	g_return_if_fail (gcentry != NULL);
-	g_return_if_fail (data != NULL);
+	g_assert (data != NULL);
 
 	if (data->func (gcentry, &value, data->user_data))
 	{
 		mozilla_pref_set (data->mozilla_pref, &value);
 		g_value_unset (&value);
 	}
+	else
+	{
+		/* Reset the pref */
+		NS_ENSURE_TRUE (gPrefBranch, );
+		gPrefBranch->ClearUserPref (data->mozilla_pref);
+	}
 }
 
 extern "C" guint
@@ -1085,19 +1094,9 @@ mozilla_notifiers_init (void)
 	eel_gconf_monitor_add ("/system/proxy");
 	eel_gconf_monitor_add ("/system/http_proxy");
 
-	/* Cache the pref branch */
-	nsresult rv;
-	nsCOMPtr<nsIPrefService> prefService
-		(do_GetService (NS_PREFSERVICE_CONTRACTID, &rv));
-	if (NS_FAILED (rv))
-	{
-		g_warning ("Failed to get the pref service!\n");
-		return FALSE;
-	}
-
 	/* the pref service conveniently implements the root pref branch */
 	gPrefBranch = nsnull;
-	rv = CallQueryInterface (prefService, &gPrefBranch);
+	nsresult rv = CallGetService (NS_PREFSERVICE_CONTRACTID, &gPrefBranch);
 	if (NS_FAILED (rv) || !gPrefBranch)
 	{
 		g_warning ("Failed to get the pref service!\n");
