@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-menu.c,v 1.39 2006/09/13 11:34:22 chpe Exp $
+ *  $Id: ephy-encoding-menu.c 6810 2007-01-09 00:40:44Z diegoe $
  */
 
 #include "config.h"
@@ -348,7 +348,7 @@ ephy_encoding_menu_automatic_cb (GtkAction *action, EphyEncodingMenu *menu)
 
 static const GtkActionEntry menu_entries [] =
 {
-	{ "ViewEncodingOther", NULL, N_("_Other..."), NULL,
+	{ "ViewEncodingOther", NULL, N_("_Other…"), NULL,
 	  N_("Other encodings"),
 	  G_CALLBACK (ephy_encoding_menu_view_dialog_cb) }
 };
