@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extensions-manager.h,v 1.7 2004/10/29 22:38:30 adamh Exp $
+ *  $Id: ephy-extensions-manager.h 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #ifndef EPHY_EXTENSIONS_MANAGER_H
@@ -44,11 +44,9 @@ typedef struct _EphyExtensionsManagerPrivate	EphyExtensionsManagerPrivate;
 typedef struct
 {
 	char *identifier;
-	char *name;
-	char *description;
-	GList *authors;
-	char *url;
-	gboolean active;
+	GKeyFile *keyfile;
+	guint active  :1;
+	guint enabled :1;
 } EphyExtensionInfo;
 	
 struct _EphyExtensionsManagerClass
