@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003  David Bordoley
- *  Copyright (C) 2003-2004 Christian Persch
+ *  Copyright © 2003  David Bordoley
+ *  Copyright © 2003-2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu.c,v 1.41 2006/03/23 16:43:28 chpe Exp $
+ *  $Id: ephy-tabs-menu.c 6588 2006-09-13 11:34:25Z chpe $
  */
 
 #include "config.h"
@@ -54,7 +54,6 @@ struct _EphyTabsMenuPrivate
 	GtkActionGroup *action_group;
 	GtkAction *anchor_action;
 	guint ui_id;
-	guint num;
 };
 
 enum
@@ -73,7 +72,7 @@ ephy_tabs_menu_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyTabsMenuClass),
 			NULL, /* base_init */
@@ -142,7 +141,8 @@ notebook_page_added_cb (EphyNotebook *notebook,
 
 	LOG ("tab_added_cb tab=%p", tab);
 
-	g_snprintf (verb, sizeof (verb), ACTION_VERB_FORMAT, priv->num++);
+	g_snprintf (verb, sizeof (verb), ACTION_VERB_FORMAT,
+		    _ephy_tab_get_id (tab));
   
 	action = g_object_new (GTK_TYPE_RADIO_ACTION,
 			       "name", verb,
@@ -250,6 +250,7 @@ sync_active_tab (EphyWindow *window,
 	/* happens initially, since the ::active-tab comes before
 	* the ::tab-added signal
 	*/
+	/* FIXME that's not true with gtk+ 2.9 anymore */
 	if (action == NULL) return;
 
 	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
